@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -145,8 +145,8 @@ typedef union YYSTYPE {
   void* extfunc;  /* for user-defined function name */
 
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 149 "y.tab.c"
+/* Line 190 of yacc.c.  */
+#line 150 "y.tab.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -157,23 +157,26 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 161 "y.tab.c"
+/* Line 213 of yacc.c.  */
+#line 162 "y.tab.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
+# ifndef YYFREE
+#  define YYFREE free
+# endif
+# ifndef YYMALLOC
+#  define YYMALLOC malloc
+# endif
+
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
-# else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
-#    endif
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -186,20 +189,20 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short yyss;
+  short int yyss;
   YYSTYPE yyvs;
   };
 
@@ -209,13 +212,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -251,7 +254,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short yysigned_char;
+   typedef short int yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -354,11 +357,11 @@ static const unsigned char yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "NUM", "EXTFUNC", "VAR", "FNCT", "OR", 
-  "AND", "strCMP", "strNE", "strEQ", "strLE", "strLT", "strGE", "strGT", 
-  "'<'", "'>'", "numNE", "numEQ", "numLE", "numLT", "numGE", "numGT", 
-  "reNOTLIKE", "reLIKE", "'-'", "'+'", "'*'", "'/'", "'%'", "'!'", "NEG", 
-  "NOT", "'^'", "'('", "')'", "','", "$accept", "line", "numEXP", 
+  "$end", "error", "$undefined", "NUM", "EXTFUNC", "VAR", "FNCT", "OR",
+  "AND", "strCMP", "strNE", "strEQ", "strLE", "strLT", "strGE", "strGT",
+  "'<'", "'>'", "numNE", "numEQ", "numLE", "numLT", "numGE", "numGT",
+  "reNOTLIKE", "reLIKE", "'-'", "'+'", "'*'", "'/'", "'%'", "'!'", "NEG",
+  "NOT", "'^'", "'('", "')'", "','", "$accept", "line", "numEXP",
   "arglist", 0
 };
 #endif
@@ -366,7 +369,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short yytoknum[] =
+static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,    60,    62,   271,   272,
@@ -417,7 +420,7 @@ static const yysigned_char yydefgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -33
-static const short yypact[] =
+static const short int yypact[] =
 {
       41,   -33,   -27,   -33,   -26,    41,    41,    41,    41,    10,
      130,    33,    41,   -23,   -23,   -23,    70,   -33,    41,    41,
@@ -539,7 +542,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrlab1
+#define YYERROR		goto yyerrorlab
 
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
@@ -567,20 +570,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -603,36 +639,30 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short *bottom, short *top)
+yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -662,9 +692,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylineno = yyrline[yyrule];
+  unsigned int yylno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylineno);
+             yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -682,8 +712,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -701,10 +730,6 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -786,15 +811,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -810,10 +835,11 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -821,6 +847,10 @@ yydestruct (yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
 
@@ -848,10 +878,10 @@ int yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -887,7 +917,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -899,9 +929,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	yyssa[YYINITDEPTH];
-  short *yyss = yyssa;
-  register short *yyssp;
+  short int yyssa[YYINITDEPTH];
+  short int *yyss = yyssa;
+  register short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -938,6 +968,9 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
+
+  yyvsp[0] = yylval;
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -963,7 +996,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -991,7 +1024,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1027,18 +1060,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1053,7 +1086,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1073,8 +1106,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1126,29 +1159,29 @@ yyreduce:
         case 2:
 #line 43 "expr.y"
     { 
-		   if (EXPRPSTR == yyvsp[0].numval.type) {
-		     expr_retval=yyvsp[0].numval.val.strval;
+		   if (EXPRPSTR == (yyvsp[0].numval).type) {
+		     expr_retval=(yyvsp[0].numval).val.strval;
 		   } else {
-		     expr_to_dbl1(&yyvsp[0].numval); 
-		     expr_retval=double_to_pstring(yyvsp[0].numval.val.dblval,left_buffer,sizeof(left_buffer));
+		     expr_to_dbl1(&(yyvsp[0].numval)); 
+		     expr_retval=double_to_pstring((yyvsp[0].numval).val.dblval,left_buffer,sizeof(left_buffer));
 		   }
 		 }
     break;
 
   case 3:
 #line 54 "expr.y"
-    { yyval.numval = yyvsp[0].numval;			}
+    { (yyval.numval) = (yyvsp[0].numval);			}
     break;
 
   case 4:
 #line 55 "expr.y"
-    { yyval.numval.type=EXPRDBL; yyval.numval.val.dblval = yyvsp[0].tptr->value.var; }
+    { (yyval.numval).type=EXPRDBL; (yyval.numval).val.dblval = (yyvsp[0].tptr)->value.var; }
     break;
 
   case 5:
 #line 58 "expr.y"
     {
-		   yyval.numval = param->CallExprUserfncFuncPtr(param, yyvsp[-3].extfunc);
+		   (yyval.numval) = param->CallExprUserfncFuncPtr(param, (yyvsp[-3].extfunc));
 		 }
     break;
 
@@ -1156,62 +1189,62 @@ yyreduce:
 #line 62 "expr.y"
     {
 		   param->InitExprArglistFuncPtr(param);
-		   yyval.numval = param->CallExprUserfncFuncPtr(param, yyvsp[-2].extfunc);
+		   (yyval.numval) = param->CallExprUserfncFuncPtr(param, (yyvsp[-2].extfunc));
 		 }
     break;
 
   case 7:
 #line 67 "expr.y"
     {
-		   yyval.numval.type=EXPRDBL;
-		   expr_to_dbl1(&yyvsp[-1].numval);
-		   yyval.numval.val.dblval = (*(yyvsp[-3].tptr->value.fnctptr))(yyvsp[-1].numval.val.dblval); 
+		   (yyval.numval).type=EXPRDBL;
+		   expr_to_dbl1(&(yyvsp[-1].numval));
+		   (yyval.numval).val.dblval = (*((yyvsp[-3].tptr)->value.fnctptr))((yyvsp[-1].numval).val.dblval); 
 		 }
     break;
 
   case 8:
 #line 72 "expr.y"
-    { DO_MATHOP(yyval.numval,+,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_MATHOP((yyval.numval),+,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 9:
 #line 73 "expr.y"
-    { DO_MATHOP(yyval.numval,-,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_MATHOP((yyval.numval),-,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 10:
 #line 74 "expr.y"
-    { DO_MATHOP(yyval.numval,*,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_MATHOP((yyval.numval),*,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 11:
 #line 76 "expr.y"
     { 
-		   yyval.numval.type=EXPRINT;
-		   expr_to_int(&yyvsp[-2].numval,&yyvsp[0].numval);
-		   yyval.numval.val.intval = yyvsp[-2].numval.val.intval % yyvsp[0].numval.val.intval;
+		   (yyval.numval).type=EXPRINT;
+		   expr_to_int(&(yyvsp[-2].numval),&(yyvsp[0].numval));
+		   (yyval.numval).val.intval = (yyvsp[-2].numval).val.intval % (yyvsp[0].numval).val.intval;
 		 }
     break;
 
   case 12:
 #line 83 "expr.y"
     {
-		   switch (yyval.numval.type=expr_to_int_or_dbl(&yyvsp[-2].numval,&yyvsp[0].numval)) {
+		   switch ((yyval.numval).type=expr_to_int_or_dbl(&(yyvsp[-2].numval),&(yyvsp[0].numval))) {
 		   case EXPRINT: 
-                   if (yyvsp[0].numval.val.intval)
-                     yyval.numval.val.intval = yyvsp[-2].numval.val.intval / yyvsp[0].numval.val.intval;
+                   if ((yyvsp[0].numval).val.intval)
+                     (yyval.numval).val.intval = (yyvsp[-2].numval).val.intval / (yyvsp[0].numval).val.intval;
                    else
                      {
-                       yyval.numval.val.intval = 0;
+                       (yyval.numval).val.intval = 0;
 		       expr_debug("division by zero","");
                      }
 		   ;break;
 		   case EXPRDBL: 
-                   if (yyvsp[0].numval.val.dblval)
-                     yyval.numval.val.dblval = yyvsp[-2].numval.val.dblval / yyvsp[0].numval.val.dblval;
+                   if ((yyvsp[0].numval).val.dblval)
+                     (yyval.numval).val.dblval = (yyvsp[-2].numval).val.dblval / (yyvsp[0].numval).val.dblval;
                    else
                      {
-                       yyval.numval.val.dblval = 0;
+                       (yyval.numval).val.dblval = 0;
 		       expr_debug("division by zero","");
                      }
 		   }
@@ -1222,12 +1255,12 @@ yyreduce:
   case 13:
 #line 106 "expr.y"
     { 
-		   switch (yyval.numval.type=yyvsp[0].numval.type) {
+		   switch ((yyval.numval).type=(yyvsp[0].numval).type) {
 		   case EXPRINT: 
-		     yyval.numval.val.intval = -yyvsp[0].numval.val.intval;
+		     (yyval.numval).val.intval = -(yyvsp[0].numval).val.intval;
 		   ;break;
 		   case EXPRDBL: 
-		     yyval.numval.val.dblval = -yyvsp[0].numval.val.dblval;
+		     (yyval.numval).val.dblval = -(yyvsp[0].numval).val.dblval;
 		   ;break;
 		   }
 		 }
@@ -1236,133 +1269,133 @@ yyreduce:
   case 14:
 #line 117 "expr.y"
     { 
-		   yyval.numval.type=EXPRDBL;
-		   expr_to_dbl(&yyvsp[-2].numval,&yyvsp[0].numval);
-		   yyval.numval.val.dblval = pow (yyvsp[-2].numval.val.dblval, yyvsp[0].numval.val.dblval);
+		   (yyval.numval).type=EXPRDBL;
+		   expr_to_dbl(&(yyvsp[-2].numval),&(yyvsp[0].numval));
+		   (yyval.numval).val.dblval = pow ((yyvsp[-2].numval).val.dblval, (yyvsp[0].numval).val.dblval);
                  }
     break;
 
   case 15:
 #line 122 "expr.y"
-    { DO_LOGOP(yyval.numval,&&,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_LOGOP((yyval.numval),&&,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 16:
 #line 123 "expr.y"
-    { DO_LOGOP(yyval.numval,||,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_LOGOP((yyval.numval),||,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 17:
 #line 124 "expr.y"
-    { DO_CMPOP(yyval.numval,>=,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_CMPOP((yyval.numval),>=,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 18:
 #line 125 "expr.y"
-    { DO_CMPOP(yyval.numval,<=,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_CMPOP((yyval.numval),<=,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 19:
 #line 126 "expr.y"
-    { DO_CMPOP(yyval.numval,!=,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_CMPOP((yyval.numval),!=,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 20:
 #line 127 "expr.y"
-    { DO_CMPOP(yyval.numval,==,yyvsp[-2].numval,yyvsp[0].numval);	}
+    { DO_CMPOP((yyval.numval),==,(yyvsp[-2].numval),(yyvsp[0].numval));	}
     break;
 
   case 21:
 #line 128 "expr.y"
-    { DO_CMPOP(yyval.numval,>,yyvsp[-2].numval,yyvsp[0].numval);		}
+    { DO_CMPOP((yyval.numval),>,(yyvsp[-2].numval),(yyvsp[0].numval));		}
     break;
 
   case 22:
 #line 129 "expr.y"
-    { DO_CMPOP(yyval.numval,<,yyvsp[-2].numval,yyvsp[0].numval);		}
+    { DO_CMPOP((yyval.numval),<,(yyvsp[-2].numval),(yyvsp[0].numval));		}
     break;
 
   case 23:
 #line 130 "expr.y"
-    { DO_LOGOP1(yyval.numval,!,yyvsp[0].numval);		}
+    { DO_LOGOP1((yyval.numval),!,(yyvsp[0].numval));		}
     break;
 
   case 24:
 #line 131 "expr.y"
-    { DO_LOGOP1(yyval.numval,!,yyvsp[0].numval);		}
+    { DO_LOGOP1((yyval.numval),!,(yyvsp[0].numval));		}
     break;
 
   case 25:
 #line 132 "expr.y"
-    { yyval.numval = yyvsp[-1].numval;			}
+    { (yyval.numval) = (yyvsp[-1].numval);			}
     break;
 
   case 26:
 #line 133 "expr.y"
     { 
-  expr_to_str(&yyvsp[-2].numval,&yyvsp[0].numval); 
-  yyval.numval.type=EXPRINT; yyval.numval.val.intval = pstring_ge (yyvsp[-2].numval.val.strval,yyvsp[0].numval.val.strval)-pstring_le (yyvsp[-2].numval.val.strval,yyvsp[0].numval.val.strval);
+  expr_to_str(&(yyvsp[-2].numval),&(yyvsp[0].numval)); 
+  (yyval.numval).type=EXPRINT; (yyval.numval).val.intval = pstring_ge ((yyvsp[-2].numval).val.strval,(yyvsp[0].numval).val.strval)-pstring_le ((yyvsp[-2].numval).val.strval,(yyvsp[0].numval).val.strval);
 }
     break;
 
   case 27:
 #line 137 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_ge,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_ge,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 28:
 #line 138 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_le,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_le,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 29:
 #line 139 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_ne,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_ne,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 30:
 #line 140 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_eq,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_eq,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 31:
 #line 141 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_gt,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_gt,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 32:
 #line 142 "expr.y"
-    { DO_TXTOP(yyval.numval,pstring_lt,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),pstring_lt,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 33:
 #line 143 "expr.y"
-    { DO_TXTOP(yyval.numval,re_like,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),re_like,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 34:
 #line 144 "expr.y"
-    { DO_TXTOP(yyval.numval,re_notlike,yyvsp[-2].numval,yyvsp[0].numval);}
+    { DO_TXTOP((yyval.numval),re_notlike,(yyvsp[-2].numval),(yyvsp[0].numval));}
     break;
 
   case 35:
 #line 149 "expr.y"
     { 
   param->InitExprArglistFuncPtr(param);
-  param->PushExprArglistFuncPtr(param,yyvsp[0].numval);
+  param->PushExprArglistFuncPtr(param,(yyvsp[0].numval));
 }
     break;
 
   case 36:
 #line 153 "expr.y"
-    { param->PushExprArglistFuncPtr(param,yyvsp[0].numval);	 }
+    { param->PushExprArglistFuncPtr(param,(yyvsp[0].numval));	 }
     break;
 
 
     }
 
-/* Line 999 of yacc.c.  */
-#line 1365 "y.tab.c"
+/* Line 1037 of yacc.c.  */
+#line 1399 "y.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1403,18 +1436,33 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
-	  yysize += yystrlen ("syntax error, unexpected ") + 1;
-	  yysize += yystrlen (yytname[yytype]);
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -1423,16 +1471,13 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = yystpcpy (yyp, yyq);
+			yyp = yystpcpy (yyp, yyprefix);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyprefix = " or ";
 		      }
 		}
 	      yyerror (yymsg);
@@ -1450,38 +1495,57 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (yychar == YYEOF)
+      if (yychar <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (yyss < yyssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-	      yydestruct (yystos[*yyssp], yyvsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+          /* If at end of input, pop the error token,
+	     then the rest of the stack, then return failure.  */
+	  if (yychar == YYEOF)
+	     for (;;)
+	       {
+
+		 YYPOPSTACK;
+		 if (yyssp == yyss)
+		   YYABORT;
+		 yydestruct ("Error: popping",
+                             yystos[*yyssp], yyvsp);
+	       }
         }
-
-      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-      yydestruct (yytoken, &yylval);
-      yychar = YYEMPTY;
-
+      else
+	{
+	  yydestruct ("Error: discarding", yytoken, &yylval);
+	  yychar = YYEMPTY;
+	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| yyerrorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+yyerrorlab:
+
+#ifdef __GNUC__
+  /* Pacify GCC when the user code never invokes YYERROR and the label
+     yyerrorlab therefore never appears in user code.  */
+  if (0)
+     goto yyerrorlab;
+#endif
+
+yyvsp -= yylen;
+  yyssp -= yylen;
+  yystate = *yyssp;
+  goto yyerrlab1;
+
+
+/*-------------------------------------------------------------.
+| yyerrlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
@@ -1503,22 +1567,22 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
-      yyvsp--;
-      yystate = *--yyssp;
 
+      yydestruct ("Error: popping", yystos[yystate], yyvsp);
+      YYPOPSTACK;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -1534,6 +1598,9 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
+  yydestruct ("Error: discarding lookahead",
+              yytoken, &yylval);
+  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
@@ -1652,7 +1719,8 @@ parse_expr (PSTRING expression, struct tmplpro_param* param_arg)
 {
   expr=expression;
   curpos=expr.begin;
-  expr_retval=(PSTRING) {expression.begin, expression.begin};
+  expr_retval.begin=expression.begin;
+  expr_retval.endnext=expression.begin;
   param=param_arg;
   is_expect_quote_like=1;
   yyparse ();
@@ -1671,6 +1739,7 @@ fill_symbuf (int is_accepted(char)) {
   static char *symbuf = 0;
   static int symbuf_length = 0;
   int i=0;
+  PSTRING retval;
   /* Initially make the buffer long enough
      for a 40-character symbol name.  */
   if (symbuf_length == 0)
@@ -1688,7 +1757,9 @@ fill_symbuf (int is_accepted(char)) {
     }
   while (curpos<=expr.endnext && is_accepted(c));
   symbuf[i] = '\0';
-  return (PSTRING) {symbuf, symbuf+i};
+  retval.begin=symbuf;
+  retval.endnext=symbuf+i;
+  return retval;
 }
 
 static 
@@ -1723,7 +1794,8 @@ yylex (void)
     PSTRING strvalue;
     char terminal_quote=c;
     curpos++;
-    strvalue = (PSTRING) {curpos, curpos};
+    strvalue.begin = curpos;
+    strvalue.endnext = curpos;
     while (curpos<expr.endnext && 
 	   (
 	    /* it's buggy, but Expr 0.0.4 compatible :( */
@@ -1791,7 +1863,9 @@ yylex (void)
 	  /* tmpl_log(NULL, TMPL_LOG_ERROR, "lex:detected cvar %s=%s\n", name.begin,varvalue.begin); */
 	}
 	if (varvalue.begin==NULL) {
-	  yylval.numval.val.strval=(PSTRING) {curpos, curpos};
+	  /*yylval.numval.val.strval=(PSTRING) {curpos, curpos};*/
+	  yylval.numval.val.strval.begin=curpos;
+	  yylval.numval.val.strval.endnext=curpos;
 	  if (param->strict) expr_debug("non-initialized variable", name.begin);
 	} else yylval.numval.val.strval=varvalue;
 	yylval.numval.type=EXPRPSTR;
