@@ -3,16 +3,16 @@
  * Author: Igor Vlasenko <vlasenko@imath.kiev.ua>
  * Created: Fri Jul  1 20:11:51 2005
  *
- * $Id: exprpstr.h,v 1.1 2005/10/18 10:47:08 igor Exp $
+ * $Id: exprpstr.h,v 1.2 2005/11/22 20:55:34 igor Exp $
  */
 
 #ifndef _EXPRPSTR_H
 #define _EXPRPSTR_H	1
 
 static
-PSTRING double_to_pstring (double, char* buf);
+PSTRING double_to_pstring (double, char* buf, size_t bufsize);
 static
-PSTRING int_to_pstring (int,char* buf);
+PSTRING int_to_pstring (int, char* buf, size_t bufsize);
 static
 int pstring_ge(PSTRING, PSTRING);
 static
